@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2009 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 #include <stdlib.h>
@@ -553,7 +548,8 @@ GtkWidget* ctk_gvi_new(NvCtrlAttributeHandle *handle,
 
     /* Get Bus related information */
 
-    get_bus_related_info(handle, &bus, &pci_bus_id);
+    get_bus_type_str(handle, &bus);
+    get_bus_id_str(handle, &pci_bus_id);
 
     /* NV_CTRL_IRQ */
 
@@ -751,25 +747,29 @@ GtkTextBuffer *ctk_gvi_create_help(GtkTextTagTable *table,
     ctk_help_para(b, &i, "This is the interrupt request line assigned to "
                   "this GVI device.");
 
-    ctk_help_heading(b, &i, "Fill A");
-    ctk_help_para(b, &i, "This reports the detected incoming video format on "
-                  "first jack on the GVI device.");
-    
-    ctk_help_heading(b, &i, "Key A");
-    ctk_help_para(b, &i, "This reports the detected incoming video format on "
-                  "second jack on the GVI device.");
-    
-    ctk_help_heading(b, &i, "Fill B");
-    ctk_help_para(b, &i, "This reports the detected incoming video format on "
-                  "third jack on the GVI device.");
-    
-    ctk_help_heading(b, &i, "Key B");
-    ctk_help_para(b, &i, "This reports the detected incoming video format on "
-                  "fourth jack on the GVI device.");
-    
-    ctk_help_heading(b, &i, "Sync Output");
-    ctk_help_para(b, &i, "This reports the output sync signal from "
-                  "the GVI device.");
+    ctk_help_heading(b, &i, "Bound GPU");
+    ctk_help_para(b, &i, "An OpenGL application can bind a GVI device to a "
+                  "GPU using the GL_NV_video_capture OpenGL extension.  The "
+                  "Bound GPU field reports if an OpenGL application has "
+                  "currently bound this GVI device to a GPU.");
+
+    ctk_help_heading(b, &i, "Input Information");
+    ctk_help_para(b, &i, "This section shows the detected video format(s) on "
+                  "each jack of the GVI device.  When condensed mode is "
+                  "selected, the detected video format is shown for each "
+                  "jack (and channel).  When detailed mode is selected, "
+                  "information pertaining to the selected jack is reported.  "
+                  "Note that the GVI device can only detect the following "
+                  "information if the incoming signal has a non-zero SMPTE "
+                  "352 payload identifier, which not all SDI devices provide.");
+
+    ctk_help_para(b, &i, "Video Format:  The detected SMPTE video format.");
+    ctk_help_para(b, &i, "Component Sampling: The detected composition of the "
+                  "channel.");
+    ctk_help_para(b, &i, "Color Space: The detected color space.");
+    ctk_help_para(b, &i, "Bites Per Component: The detected number of bits "
+                  "per component.");
+    ctk_help_para(b, &i, "Link ID: The detected link ID of the channel.");
 
     ctk_help_finish(b);
 
