@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2004 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 #include <gtk/gtk.h>
@@ -260,8 +255,8 @@ static GtkWidget * add_scale(CtkConfig *ctk_config,
  */
 
 static void post_scale_value_changed(GtkAdjustment *adjustment,
-                                          CtkImageSliders *ctk_image_sliders,
-                                          gint value)
+                                     CtkImageSliders *ctk_image_sliders,
+                                     gint value)
 {
     char *name = g_object_get_data(G_OBJECT(adjustment), "attribute name");
     
@@ -405,7 +400,6 @@ static void scale_value_received(GtkObject *object, gpointer arg1,
         scale = ctk_image_sliders->image_sharpening;
         if (event_struct->availability == FALSE) {
             gtk_widget_set_sensitive(scale, FALSE);
-            gtk_widget_hide(scale);
             g_object_set_data(G_OBJECT(CTK_SCALE(scale)->gtk_adjustment),
                               "attribute active",
                               GINT_TO_POINTER(0));
@@ -413,10 +407,15 @@ static void scale_value_received(GtkObject *object, gpointer arg1,
             setup_scale(ctk_image_sliders, NV_CTRL_IMAGE_SHARPENING,
                         ctk_image_sliders->image_sharpening);
             gtk_widget_set_sensitive(scale, TRUE);
-            gtk_widget_show(scale);
             g_object_set_data(G_OBJECT(CTK_SCALE(scale)->gtk_adjustment),
                               "attribute active",
                               GINT_TO_POINTER(1));
+            /* In case of image sharpening slider here we are syncing to the 
+             * recent image sharpening value, so updating status bar message */
+            post_scale_value_changed(CTK_SCALE(scale)->gtk_adjustment,
+                                     ctk_image_sliders,
+                                     gtk_adjustment_get_value(
+                                             CTK_SCALE(scale)->gtk_adjustment));
         }
         break;
     default:
@@ -516,28 +515,22 @@ static void setup_scale(CtkImageSliders *ctk_image_sliders,
                       GINT_TO_POINTER(1));
 
         gtk_widget_set_sensitive(scale, TRUE);
-        gtk_widget_show(scale);
     } else {
         g_object_set_data(G_OBJECT(adj), "attribute active",
                       GINT_TO_POINTER(0));
 
         gtk_widget_set_sensitive(scale, FALSE);
-        gtk_widget_hide(scale);
     }
 
 } /* setup_scale() */
 
 
-
 /*
  * Updates the page to reflect the current configuration of
  * the display device.
  */
 void ctk_image_sliders_setup(CtkImageSliders *ctk_image_sliders)
 {
-    int active;
-
-
     if (!ctk_image_sliders) return;
 
     /* Update sliders */
@@ -557,15 +550,11 @@ void ctk_image_sliders_setup(CtkImageSliders *ctk_image_sliders)
     setup_scale(ctk_image_sliders, NV_CTRL_IMAGE_SHARPENING,
                 ctk_image_sliders->image_sharpening);
 
-    active =
-        get_scale_active(CTK_SCALE(ctk_image_sliders->digital_vibrance)) ||
-        get_scale_active(CTK_SCALE(ctk_image_sliders->overscan_compensation)) ||
-        get_scale_active(CTK_SCALE(ctk_image_sliders->image_sharpening));
-
-    if (!active) {
-        gtk_widget_hide(ctk_image_sliders->frame);
-    } else {
-        gtk_widget_show(ctk_image_sliders->frame);
-    }
+    gtk_widget_set_sensitive(ctk_image_sliders->digital_vibrance,
+        get_scale_active(CTK_SCALE(ctk_image_sliders->digital_vibrance)));
+    gtk_widget_set_sensitive(ctk_image_sliders->overscan_compensation,
+        get_scale_active(CTK_SCALE(ctk_image_sliders->overscan_compensation)));
+    gtk_widget_set_sensitive(ctk_image_sliders->image_sharpening,
+        get_scale_active(CTK_SCALE(ctk_image_sliders->image_sharpening)));
 
 } /* ctk_image_sliders_setup() */
