@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2004 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 /*
@@ -33,6 +28,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "ctkwindow.h"
 
@@ -73,6 +69,10 @@
 #include "ctkevent.h"
 #include "ctkconstants.h"
 
+#include "msg.h"
+#include "common-utils.h"
+
+
 /* column enumeration */
 
 enum {
@@ -128,6 +128,9 @@ static void add_display_devices(CtkWindow *ctk_window, GtkTreeIter *iter,
 static void update_display_devices(GtkObject *object, gpointer arg1,
                                    gpointer user_data);
 
+static void ctk_window_destroyed(GtkObject *object, gpointer arg1,
+                                 gpointer user_data);
+
 
 static GObjectClass *parent_class;
 
@@ -200,6 +203,19 @@ static void ctk_window_real_destroy(GtkObject *object)
 
 
 
+/* 
+ * ctk_window_destroyed() - called when ctk_window destroyed.
+ */
+
+static void ctk_window_destroyed(GtkObject *object, gpointer arg1,
+                                 gpointer user_data)
+{
+    CtkWindow *ctk_window = CTK_WINDOW(object);
+    save_settings_and_exit(ctk_window);
+} /* ctk_window_destroyed() */
+
+
+
 /*
  * close_button_clicked() - called when the "Quit" button is clicked.
  */
@@ -797,12 +813,6 @@ GtkWidget *ctk_window_new(ParsedAttribute *p, ConfigProperties *conf,
         gtk_tree_store_set(ctk_window->tree_store, &iter,
                            CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
                            NULL, -1);
-        gtk_tree_store_set(ctk_window->tree_store, &iter,
-                           CTK_WINDOW_SELECT_WIDGET_FUNC_COLUMN,
-                           ctk_gpu_start_timer, -1);
-        gtk_tree_store_set(ctk_window->tree_store, &iter,
-                           CTK_WINDOW_UNSELECT_WIDGET_FUNC_COLUMN,
-                           ctk_gpu_stop_timer, -1);
 
         /* power savings */
 
@@ -847,7 +857,7 @@ GtkWidget *ctk_window_new(ParsedAttribute *p, ConfigProperties *conf,
                      NULL, ctk_ecc_start_timer, ctk_ecc_stop_timer);
         }
         /* display devices */
-        data = (UpdateDisplaysData *)calloc(1, sizeof(UpdateDisplaysData));
+        data = calloc(1, sizeof(UpdateDisplaysData));
         data->window = ctk_window;
         data->event = ctk_event;
         data->gpu_handle = gpu_handle;
@@ -1076,12 +1086,96 @@ GtkWidget *ctk_window_new(ParsedAttribute *p, ConfigProperties *conf,
                                        GTK_POLICY_AUTOMATIC);
     }
 
+    /* Add callback when window destroyed */
+
+    g_signal_connect(G_OBJECT(ctk_window), "destroy",
+                     G_CALLBACK(ctk_window_destroyed), (gpointer) ctk_window);
+    
     return GTK_WIDGET(object);
 
 } /* ctk_window_new() */
 
 
 
+/*
+ * Set the currently active page to be the page that matches the
+ * specified label.
+ *
+ * Note that child pages of X screens and GPUs cannot be uniquely
+ * identified by their label alone (e.g., each GPU has a "PowerMizer"
+ * page).  To allow explicit control over which instance of a child
+ * page is selected, the label can have the optional format
+ *
+ *  "[PARENT LABEL], [CHILD LABEL]"
+ *
+ * E.g.,
+ *
+ *  "GPU 0 - (GeForce 7600 GT), PowerMizer"
+ */
+
+typedef struct {
+    CtkWindow *ctk_window;
+    const gchar *label;
+} ctk_window_set_active_page_args;
+
+static gboolean ctk_window_set_active_page_callback(GtkTreeModel *model,
+                                                    GtkTreePath *path,
+                                                    GtkTreeIter *iter,
+                                                    gpointer data)
+{
+    GtkTreeIter parent;
+    gboolean valid;
+    gchar *iter_label;
+    gchar *parent_label = "no parent";
+    gchar *qualified_label;
+    ctk_window_set_active_page_args *args = data;
+
+    /* get the parent's label, if there is a parent */
+
+    valid = gtk_tree_model_iter_parent(model, &parent, iter);
+    if (valid) {
+        gtk_tree_model_get(model, &parent,
+                           CTK_WINDOW_LABEL_COLUMN, &parent_label, -1);
+    }
+
+    gtk_tree_model_get(model, iter, CTK_WINDOW_LABEL_COLUMN, &iter_label, -1);
+
+    qualified_label = nvstrcat(parent_label, ", ", iter_label, NULL);
+
+    if ((strcmp(iter_label, args->label) == 0) ||
+        (strcmp(qualified_label, args->label) == 0)) {
+        GtkTreeSelection* selection;
+        selection = gtk_tree_view_get_selection(args->ctk_window->treeview);
+        gtk_tree_selection_select_iter(selection, iter);
+        free(qualified_label);
+        return TRUE; /* stop walking the tree */
+    }
+
+    free(qualified_label);
+
+    return FALSE; /* keep walking the tree */
+}
+
+
+void ctk_window_set_active_page(CtkWindow *ctk_window, const gchar *label)
+{
+    GtkTreeModel *model = GTK_TREE_MODEL(ctk_window->tree_store);
+
+    ctk_window_set_active_page_args args;
+
+    if (!label) return;
+
+    args.ctk_window = ctk_window;
+    args.label = label;
+
+    gtk_tree_model_foreach(model,
+                           ctk_window_set_active_page_callback,
+                           &args);
+
+} /* ctk_window_set_active_page() */
+
+
+
 /*
  * add_page() - add a new page to ctk_window's tree_store, using iter
  * as a parent; the new child iter is written in pchild_iter, if
@@ -1229,26 +1323,34 @@ static void quit_response(GtkWidget *button, gint response, gpointer user_data)
  * saved to the config file.
  */
 
+static gboolean add_special_config_file_attributes_callback(GtkTreeModel *model,
+                                                            GtkTreePath *path,
+                                                            GtkTreeIter *iter,
+                                                            gpointer data)
+{
+    GtkWidget *widget;
+    config_file_attributes_func_t func;
+    CtkWindow *ctk_window = data;
+
+    gtk_tree_model_get(model, iter,
+                       CTK_WINDOW_WIDGET_COLUMN, &widget,
+                       CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
+                       &func, -1);
+
+    if (func) (*func)(widget, ctk_window->attribute_list);
+
+    return FALSE; /* keep iterating over nodes in the tree */
+}
+
+
 void add_special_config_file_attributes(CtkWindow *ctk_window)
 {
     GtkTreeModel *model = GTK_TREE_MODEL(ctk_window->tree_store);
-    GtkTreeIter   iter;
-    gboolean valid;
-    config_file_attributes_func_t func;
-    GtkWidget *widget;
-    
-    valid = gtk_tree_model_get_iter_first(model, &iter);
-    while (valid) {
-        
-        gtk_tree_model_get(model, &iter,
-                           CTK_WINDOW_WIDGET_COLUMN, &widget,
-                           CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
-                           &func, -1);
-        
-        if (func) (*func)(widget, ctk_window->attribute_list);
-        
-        valid = gtk_tree_model_iter_next(model, &iter);
-    }
+
+    gtk_tree_model_foreach(model,
+                           add_special_config_file_attributes_callback,
+                           ctk_window);
+
 } /* add_special_config_file_attributes() */
 
 
@@ -1292,8 +1394,7 @@ static void add_display_devices(CtkWindow *ctk_window, GtkTreeIter *iter,
     if (data->display_iters) {
         free(data->display_iters);
     }
-    data->display_iters =
-        (GtkTreeIter *)calloc(1, n * sizeof(GtkTreeIter));
+    data->display_iters = calloc(n, sizeof(GtkTreeIter));
     data->num_displays = 0;
     if (!data->display_iters) return;
 
